==> blogmate-0.1.4.tgz: package/lib/blogmate.js <==
(function() {
  var express, form, helpers, path;
  require('sugar');
  express = require('express');
  path = require('path');
  form = require('connect-form');
  helpers = require('./helpers');
  module.exports = {
    start: function(port) {
      return app.listen(port);
    },
    init: function(app_dir, conf) {
      var uri;
      global.app = express.createServer(form({
        keepExtensions: true
      }));
      app.conf = conf;
      uri = process.env["MONGOHQ_URL"];
      if (!uri) {
        uri = "mongodb://localhost/" + conf.database_name;
      }
      console.log("Use database: " + uri);
      app.mongoose = require('mongoose');
      app.db = app.mongoose.connect(uri);
      app.configure(function() {
        app.use(express.static(path.join(app_dir, 'public')));
        app.use(express.bodyParser());
        app.use(express.cookieParser());
        app.use(express.session({
          secret: "this_is_super_secret_string",
          cookie: {
            maxAge: 86400000
          }
        }));
        app.use(app.router);
        return app.use(express.errorHandler({
          showStack: true,
          dumpExceptions: true
        }));
      });
      app.get('/*', function(req, res, next) {
        req.conf = app.conf;
        req.helpers = helpers;
        return next();
      });
      if (conf.redirect_www) {
        app.get('/*', function(req, res, next) {
          if (req.headers.host.match(/^www\./)) {
            return res.redirect("http://" + (req.headers.host.replace(/^www\./, '')) + req.url, 301);
          } else {
            return next();
          }
        });
      }
      require('./templates');
      return require('./blog');
    }
  };
}).call(this);

==> blogmate-0.1.5.tgz: package/lib/blogmate.js <==
(function() {
  var express, form, helpers, path;
  require('sugar');
  express = require('express');
  path = require('path');
  form = require('connect-form');
  helpers = require('./helpers');
  module.exports = {
    start: function(port) {
      return app.listen(port);
    },
    init: function(app_dir, conf) {
      var uri;
      global.app = express.createServer(form({
        keepExtensions: true
      }));
      app.conf = conf;
      uri = process.env["MONGOHQ_URL"];
      if (!uri) {
        uri = "mongodb://localhost/" + conf.database_name;
      }
      console.log("Use database: " + uri);
      app.mongoose = require('mongoose');
      app.db = app.mongoose.connect(uri);
      app.configure(function() {
        app.use(express.methodOverride());
        app.use(express.bodyParser());
        app.use(express.cookieParser());
        app.use(express.session({
          secret: "this_is_super_secret_string",
          cookie: {
            maxAge: 86400000
          }
        }));
        app.use(app.router);
        app.use(express.static(path.join(app_dir, 'static')));
        return app.use(express.errorHandler({
          showStack: true,
          dumpExceptions: true
        }));
      });
      app.get('/*', function(req, res, next) {
        req.conf = app.conf;
        req.helpers = helpers;
        return next();
      });
      if (conf.redirect_www) {
        app.get('/*', function(req, res, next) {
          if (req.headers.host.match(/^www\./)) {
            return res.redirect("http://" + (req.headers.host.replace(/^www\./, '')) + req.url, 301);
          } else {
            return next();
          }
        });
      }
      require('./templates');
      return require('./blog');
    }
  };
}).call(this);
